@@ -46,7 +46,7 @@ class Ring:
         self.module_write(**args)
         self.sequence += 1
         logger.debug(
-            f'{self.__class__.__name.lower()}.write data_type={self.data_type.__name__} '
+            f'{self.__class__.__name__.lower()}.write data_type={self.data_type.__name__} '
             f'module_id={self.module_id} ring={self.ring} num_packets={len(data)} '
             f'sequence={self.sequence}'
         )
@@ -61,7 +61,7 @@ class Ring:
         params.update(kwargs)
         data = self.module_read(*args, **params)
         logger.debug(
-            f'{self.__class__.__name.lower()}.read data_type={self.data_type.__name__} '
+            f'{self.__class__.__name__.lower()}.read data_type={self.data_type.__name__} '
             f'module_id={self.module_id} ring={self.ring} num_packets={len(data)}'
         )
         return [self.data_type.fromDict(item) for item in data]
